didChangeAppLifecycleState method

  1. @override
  2. @mustCallSuper
void didChangeAppLifecycleState(
  1. AppLifecycleState state
)
override

Called when the system puts the app in the background or returns the app to the foreground.

An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.

This method exposes notifications from SystemChannels.lifecycle.

See also:

Implementation

@override
@mustCallSuper
void didChangeAppLifecycleState(AppLifecycleState state) {
  super.didChangeAppLifecycleState(state);
  Alog.i(
      tag: tag, moduleName: _moduleName, content: "$tag ${state.toString()}");
  onAppLifecycleState(state);
}