DialogUtils class

Constructors

DialogUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showChildNavigatorDialog<T extends Object>(BuildContext context, Widget widgetPage) Future<T?>
showChildNavigatorPopup<T extends Object>(BuildContext context, Widget widgetPage) Future<T?>
showCommonDialog(BuildContext context, String title, String content, VoidCallback cancelCallback, VoidCallback acceptCallback, {String cancelText = UIStrings.cancel, String acceptText = UIStrings.sure, bool canBack = true, bool isContentCenter = true}) Future
showInviteDialog(BuildContext context, String content) → void
showOneButtonCommonDialog(BuildContext context, String title, String content, VoidCallback callback, {String acceptText = UIStrings.iKnow, bool canBack = true, bool isContentCenter = true}) Future
showOpenAudioDialog(BuildContext context, String title, String content, VoidCallback cancelCallback, VoidCallback acceptCallback) Future
showOpenVideoDialog(BuildContext context, String title, String content, VoidCallback cancelCallback, VoidCallback acceptCallback) Future
showShareScreenDialog(BuildContext context, String title, String content, VoidCallback acceptCallback) → void